@@ -1,11 +1,11 @@
-use std::{any::Any, net::{IpAddr, Ipv4Addr, SocketAddr}, sync::{Arc, Mutex}};
+use std::{net::{IpAddr, Ipv4Addr, SocketAddr}};
 
 use tokio::runtime::Runtime;
 use warp::{Filter, fs::dir};
 
-use crate::{app::{WarpInitData, WarpSettings}, headers::add_headers};
+use crate::{app::{AppState, WarpInitData, WarpSettings}, headers::add_headers};
 
-pub fn start(rt: &Runtime, settings: WarpSettings, state: Arc<Mutex<Box<dyn Any + Send>>>)-> () {
+pub fn start(rt: &Runtime, settings: WarpSettings, state: AppState)-> () {
     let socket_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), settings.port);
     let static_dir = ".";
     if let Some(init_fn) = settings.init_fn {
